/*
 *	Hardware Abstraction Layer methods implementation.
 *	Created for the SD_CardLib.
 *
 * 	This file relies on the driverlib of Ti 1.90.00.65
 * 	This driverlib is to be used with the MSP430F5xxx_6xxx family
 *  Last Revision on: 29.08.2014
 *  Version: 0.9.00
 *  Copyright 2014, Micronas GmbH.
 *  Author: Nessim Ben Ammar
 *
 */



#include "msp430.h"
#include "driverlib.h"
#include "HAL.h"

#define GPIO_ALL	GPIO_PIN0|GPIO_PIN1|GPIO_PIN2|GPIO_PIN3| \
					GPIO_PIN4|GPIO_PIN5|GPIO_PIN6|GPIO_PIN7

// ________________________________________________________________________________________________

/*
 * This method stops the watchdog timer.
 *
 */

void HAL_StopWatchdog()
{
	WDT_A_hold(WDT_A_BASE);
}

// ________________________________________________________________________________________________

/*
 * This method configures the system clocks and the Power Management module:
 * MCLK = SMCLK = DCO/FLL = SYS_CLK
 * ACLK = FLLref = REFO=32kHz
 *
 * XT2 is not configured here.  Instead, the USB API automatically starts XT2
 * when beginning USB communication, and optionally disables it during USB
 * suspend.  It's left running after the USB host is disconnected, at which
 * point you're free to disable it.  You need to configure the XT2 frequency
 * in the USB Descriptor Tool.
 *
 */

void HAL_InitClocks()
{
	// Minimum VCore setting required for the USB API is PMM_CORE_LEVEL_2.
	// VCore is set to PMM_CORE_LEVEL_3 to allow 20 MHz operation.
	PMM_setVCore(PMM_CORE_LEVEL_3);
	// Set SVS high side to full performance.
	PMM_SvsHEnabledInLPMFullPerf();
	UCS_clockSignalInit(UCS_FLLREF, UCS_REFOCLK_SELECT, UCS_CLOCK_DIVIDER_1);
	UCS_clockSignalInit(UCS_ACLK, UCS_REFOCLK_SELECT, UCS_CLOCK_DIVIDER_1);
	UCS_initFLLSettle(SYS_CLK / 1000, SYS_CLK / 32768);
}

// ________________________________________________________________________________________________

/*
 * This method drives all the I/O's as output-low, to avoid floating inputs
 * (which cause extra power to be consumed). Only the Corresponding pins
 * to the PORT_Px_PULLUP defined in HAL.h are set as output high.
 * Remember, this function used to switch all possible pins:
 * For their proper functions, the pins must be reassigned after
 * calling this method.
 *
 */

void HAL_InitPorts()
{
#ifdef __MSP430_HAS_PORT1_R__
#ifdef PORT_P1_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P1, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P1, PORT_P1_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P1, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P1, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORT2_R__
#ifdef PORT_P2_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P2, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P2, PORT_P2_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P2, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P2, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORT3_R__
#ifdef PORT_P3_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P3, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P3, PORT_P3_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P3, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P3, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORT4_R__
#ifdef PORT_P4_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P4, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P4, PORT_P4_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P4, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P4, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORT5_R__
#ifdef PORT_P5_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P5, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P5, PORT_P5_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P5, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P5, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORT6_R__
#ifdef PORT_P6_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P6, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P6, PORT_P6_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P6, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P6, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORT7_R__
#ifdef PORT_P7_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P7, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P7, PORT_P7_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P7, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P7, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORT8_R__
#ifdef PORT_P8_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P8, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P8, PORT_P8_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P8, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P8, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORT9_R__
#ifdef PORT_P9_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_P9, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_P9, PORT_P9_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_P9, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_P9, GPIO_ALL);
#endif

#ifdef __MSP430_HAS_PORTJ_R__
#ifdef PORT_PJ_PULLUP
	GPIO_setOutputLowOnPin(GPIO_PORT_PJ, GPIO_ALL);
	GPIO_setOutputHighOnPin(GPIO_PORT_PJ, PORT_PJ_PULLUP);
#else
	GPIO_setOutputLowOnPin(GPIO_PORT_PJ, GPIO_ALL);
#endif
	GPIO_setAsOutputPin(GPIO_PORT_PJ, GPIO_ALL);
#endif
}
