/*
 *	Hardware Abstraction Layer
 *
 *	Header file for the Hardware Abstraction Layer library to be used with any
 *	MSP430F5xxx/6xxx C. Contains simple helpful function to initialize ports,
 *	clocks etc...
 *
 *  This header file is used by the software library for SD_Cards.
 *	The defined names of the SD_Cardinterface
 *	in this header are used in other source files.
 *	Do not change the names, simply adjust the pin, port numbers
 *	and the base addresses.
 *	If a certain pin is not used, comment it out along with its port.
 *	Do not delete, you may want to use it again later.
 *
 *	You should expand this file to include all the pin / port
 *	definitions of your project, then share the same HAL.h file...
 *
 *
 * 	This file relies on the driverlib of Ti 1.90.00.65
 * 	This driverlib is to be used with the MSP430F5xxx_6xxx family
 *  Last Revision on: 29.08.2014
 *  Version: 0.9.00
 *  Copyright 2014, Micronas GmbH.
 *  Author: Nessim Ben Ammar
 *
 */

#ifndef HAL_H_
#define HAL_H_

// 	System Clocks
#define SYS_CLK 							0x1312D00					// System clock Frequency in Hz
#define AUX_CLK 							0x8000						// Auxiliary clock frequency in Hz
// NOTE: keep this clock to 32768 hex 0x8000
// Or rewrite the GASB_EnterLPM method.

#define INFOA_START						0x001980					// Flash user information segment A starting address.
#define INFOA_END							0x0019FF					// Flash information segment A ending address.

// ________________________________________________________________________________________________

/*
 * System pull up pins:
 * For current leakage, all IO Pins will be set to output low (GND).
 * Some pins might be physically tied to VCC over pull ups.
 * Those need to be set as output high otherwise a current shortcut is made.
 *
 */

#define PORT_P1_PULLUP						GPIO_PIN5
#define PORT_P2_PULLUP						GPIO_PIN1 | GPIO_PIN2
#define PORT_P8_PULLUP						GPIO_PIN7



// ________________________________________________________________________________________________

// SD-Card definitions
#define SD_SPI_PORT						GPIO_PORT_P8
#define SD_SPI_SIMO       		GPIO_PIN5
#define SD_SPI_SOMI      			GPIO_PIN6
#define SD_SPI_CLK    				GPIO_PIN4
#define SD_CS_PORT						GPIO_PORT_P8
#define SD_CS_PIN     		    GPIO_PIN7
#define SD_INS_PORT						GPIO_PORT_P1			// SD insertion / removal detection port
#define SD_INS_PIN						GPIO_PIN5					// SD insertion / removal detection pin
																								// Comment both SD_INS lines if not used.

// SPI USCI base address.
#define SD_SPI_BASE						USCI_B1_BASE

// Timer_A
#define SD_TIMER_BASE					TIMER_A0_BASE

// Functional PINs
#define SD_ERRORLED_PORT			GPIO_PORT_P5			// Error LED
#define SD_ERRORLED_PIN     	GPIO_PIN5
#define SD_WARNLED_PORT				GPIO_PORT_P5			// Error LED
#define SD_WARNLED_PIN     		GPIO_PIN4

// ________________________________________________________________________________________________

// General Purpose Methods
extern void HAL_StopWatchdog();
extern void HAL_InitClocks();
extern void HAL_InitPorts();


#endif /* HAL_H_ */
