/*
 *  Software library for SD-Cards.
 * 	To be used with one SD-Card connected to the MCU via SPI.
 * 	Do not use this library with USB Mass Storage Class!
 *
 * 	This library relies on the driverlib of Ti 1.90.00.65
 * 	This driverlib is to be used with the MSP430F5xxx_6xxx family
 *  Last Revision on: 29.08.2014
 *  Version: 0.9.00
 *  Copyright 2014, Micronas GmbH.
 *  Author: Nessim Ben Ammar
 */
#include "driverlib.h"
#include <stdbool.h>
#include <cstring>
#include "FatFs/mmc.h"
#include "FatFs/ff.h"
#include "HAL.h"

#ifndef SD_CARD_H_
#define SD_CARD_H_

#define SD_AFLAG_INSRT			0x01		/* SD card is present. 				*/
#define SD_AFLAG_FSMNT			0x02		/* File system is mounted. 		*/
#define SD_AFLAG_FIOPN			0x04		/* File is opened.						*/

#define SD_EFLAG_INSRT			0x01		/* No SD card is present. 		*/
#define SD_EFLAG_FSMNT			0x02		/* Error mounting FS. 				*/
#define SD_EFLAG_FIOPN			0x04		/* Error opening File					*/
#define SD_EFLAG_FIWRT			0x08		/* Error while writing.				*/
#define SD_EFLAG_FICLS			0x10		/* Error while closing file.	*/
#define SD_EFLAG_MKDIR			0x20		/* Error creating directory.	*/

extern FATFS SD_FileSystemObject;
extern FIL SD_FileObject;
extern volatile uint8_t SD_EREG;
extern volatile uint8_t SD_AREG;

extern void SD_Init();
extern void SD_DetectCard();
extern void SD_MountFS();
extern void SD_UnmountFS();
extern void SD_MkDir(char * dirName);
extern void SD_OpentFile(char * fileName);
extern void SD_WriteToFile(char * entry);
extern void SD_CloseFile();
extern void SD_ClearErrors();

#endif /* SD_CARD_H_ */
